# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .day_of_week_dto import DayOfWeekDto
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class FreshnessRules(UniversalBaseModel):
    months: typing.Optional[typing.List[int]] = None
    days_of_month: typing.Optional[typing.List[int]] = None
    days_of_week: typing.Optional[typing.List[DayOfWeekDto]] = None
    hours: typing.Optional[typing.List[int]] = None
    minutes: typing.Optional[typing.List[int]] = None
    seconds: typing.Optional[typing.List[int]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
