# This file was auto-generated by Fern from our API Definition.

import typing

DayOfWeekDto = typing.Union[
    typing.Literal[
        "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
    ],
    typing.Any,
]
