# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .tool_call import ToolCall
from .message_generation_inspection import MessageGenerationInspection
from .preparation_iteration import PreparationIteration
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class EventTrace(UniversalBaseModel):
    tool_calls: typing.List[ToolCall]
    message_generations: typing.List[MessageGenerationInspection]
    preparation_iterations: typing.List[PreparationIteration]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
