# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..types.payload import Payload
from ..core.request_options import RequestOptions
from ..types.evaluation import Evaluation
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.jsonable_encoder import jsonable_encoder
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EvaluationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        agent_id: str,
        payloads: typing.Sequence[Payload],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Evaluation:
        """
        Parameters
        ----------
        agent_id : str

        payloads : typing.Sequence[Payload]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Evaluation
            Successful Response

        Examples
        --------
        from parlant.client import ParlantClient, Payload

        client = ParlantClient(
            base_url="https://yourhost.com/path/to/api",
        )
        client.evaluations.create(
            agent_id="agent_id",
            payloads=[Payload()],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "index/evaluations",
            method="POST",
            json={
                "agent_id": agent_id,
                "payloads": convert_and_respect_annotation_metadata(
                    object_=payloads,
                    annotation=typing.Sequence[Payload],
                    direction="write",
                ),
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Evaluation,
                    parse_obj_as(
                        type_=Evaluation,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def retrieve(
        self,
        evaluation_id: str,
        *,
        wait_for_completion: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Evaluation:
        """
        Parameters
        ----------
        evaluation_id : str

        wait_for_completion : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Evaluation
            Successful Response

        Examples
        --------
        from parlant.client import ParlantClient

        client = ParlantClient(
            base_url="https://yourhost.com/path/to/api",
        )
        client.evaluations.retrieve(
            evaluation_id="evaluation_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"index/evaluations/{jsonable_encoder(evaluation_id)}",
            method="GET",
            params={
                "wait_for_completion": wait_for_completion,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Evaluation,
                    parse_obj_as(
                        type_=Evaluation,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncEvaluationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        agent_id: str,
        payloads: typing.Sequence[Payload],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Evaluation:
        """
        Parameters
        ----------
        agent_id : str

        payloads : typing.Sequence[Payload]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Evaluation
            Successful Response

        Examples
        --------
        import asyncio

        from parlant.client import AsyncParlantClient, Payload

        client = AsyncParlantClient(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.evaluations.create(
                agent_id="agent_id",
                payloads=[Payload()],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "index/evaluations",
            method="POST",
            json={
                "agent_id": agent_id,
                "payloads": convert_and_respect_annotation_metadata(
                    object_=payloads,
                    annotation=typing.Sequence[Payload],
                    direction="write",
                ),
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Evaluation,
                    parse_obj_as(
                        type_=Evaluation,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def retrieve(
        self,
        evaluation_id: str,
        *,
        wait_for_completion: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Evaluation:
        """
        Parameters
        ----------
        evaluation_id : str

        wait_for_completion : typing.Optional[int]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Evaluation
            Successful Response

        Examples
        --------
        import asyncio

        from parlant.client import AsyncParlantClient

        client = AsyncParlantClient(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.evaluations.retrieve(
                evaluation_id="evaluation_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"index/evaluations/{jsonable_encoder(evaluation_id)}",
            method="GET",
            params={
                "wait_for_completion": wait_for_completion,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    Evaluation,
                    parse_obj_as(
                        type_=Evaluation,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
